capabilities

package
v0.0.0-...-29f19f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 28, 2021 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const Bamboo string = "bamboo"

Bamboo We will do branch detection based on the environment variable set by Bamboo (`planRepository.branchDisplayName`)

const Git string = "git"

Git We will do branch detection based on the `git` command output TODO: which command exactly?

const Jenkins string = "jenkins"

Jenkins We will do branch detection based on the environment variable set by Jenkins (`GIT_BRANCH`)

Variables

This section is empty.

Functions

func BranchingDetectionMethods

func BranchingDetectionMethods() UniqueStringList

BranchingDetectionMethods Retrieve possible branching detection methods

Types

This section is empty.

Jump to