util

package
v0.0.0-...-29f19f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 28, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetBranchName

func GetBranchName(c *typeconfig.TypeConfig) (string, error)

GetBranchName Pull out branch name, however appropriate, return it as lowered string

func OutputBranchName

func OutputBranchName(splitParts []string) string

OutputBranchName Combines splti branch name elements into the string appendable to the YYYY.MM.* part

func SplitBranchName

func SplitBranchName(branchName string) []string

SplitBranchName Splits branch name by any non-alphanumerics in there

Types

This section is empty.

Jump to