typeconfig

package
v0.0.0-...-29f19f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 28, 2021 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TypeConfig

type TypeConfig struct {
	TimeValue                  time.Time
	TimeZoneLocation           time.Location
	BranchingDetection         string
	BranchingFallBackDetection bool
	// contains filtered or unexported fields
}

TypeConfig data type to hold all variable config directives

func Config

func Config(sTime string, location string, branchingMethod string, branchingFallback bool,
	branchingFallbackMethods string) (*TypeConfig, error)

Config Instance of the configuration directives with sanity checking in place

func (*TypeConfig) BranchingFallbackDetectionMechanisms

func (tc *TypeConfig) BranchingFallbackDetectionMechanisms() uniquestringlist.UniqueStringList

BranchingFallbackDetectionMechanisms returns the private struct member branchingFallBackDetectionMechanisms

func (*TypeConfig) SetBranchingFallbackDetectionMechanisms

func (tc *TypeConfig) SetBranchingFallbackDetectionMechanisms(s ...string) error

SetBranchingFallbackDetectionMechanisms sets the private struct member branchingFallBackDetectionMechanisms from the multiple strings parameters

func (*TypeConfig) SetBranchingFallbackDetectionMechanismsFromString

func (tc *TypeConfig) SetBranchingFallbackDetectionMechanismsFromString(s string) error

SetBranchingFallbackDetectionMechanismsFromString sets the private struct member branchingFallBackDetectionMechanisms from the string input of comma-separated values

Jump to