Documentation
¶
Index ¶
Constants ¶
const Bamboo string = "bamboo"
Bamboo We will do branch detection based on the environment variable set by Bamboo (`planRepository.branchDisplayName`)
const Git string = "git"
Git We will do branch detection based on the `git` command output TODO: which command exactly?
const Jenkins string = "jenkins"
Jenkins We will do branch detection based on the environment variable set by Jenkins (`GIT_BRANCH`)
Variables ¶
This section is empty.
Functions ¶
func BranchingDetectionMethods ¶
func BranchingDetectionMethods() UniqueStringList
BranchingDetectionMethods Retrieve possible branching detection methods
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.