Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetBranchName ¶
func GetBranchName(c *typeconfig.TypeConfig) (string, error)
GetBranchName Pull out branch name, however appropriate, return it as lowered string
func OutputBranchName ¶
OutputBranchName Combines splti branch name elements into the string appendable to the YYYY.MM.* part
func SplitBranchName ¶
SplitBranchName Splits branch name by any non-alphanumerics in there
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.